@@ -54,9 +54,9 @@ class SqlAlchemyOperator:
             inspector = inspect(connection)
             return inspector.get_columns(table)
 
-    def table_to_orm_file(self, table: str, file: Path):
+    def table_to_orm_file(self, table: str, file_path: Path):
         columns = self.get_table_column_list(table)
-        with open(file, "w") as file:
+        with open(file_path, "w") as file:
             file.write("class {}(Base):\n".format(table))
             file.write("    __tablename__ = '{}'\n\n".format(table))
             for column in columns:
@@ -72,17 +72,17 @@ class SqlAlchemyOperator:
             file.write("\n")
 
     def get_table_metadata(self, table: str) -> Table:
-        metadata = MetaData
+        metadata = MetaData()
         return Table(table, metadata, autoload_with=self.engine)
 
     def get_alchemy_version(self) -> str:
         return sqlalchemy.__version__
 
-    def is_table_exist(self, table: str):
+    def is_table_exist(self, table: str) -> bool:
         tables = self.get_table_list()
         if table in tables:
             return True
-        raise Exception("{} table does not exist in table list {}.".format(table, tables))
+        return False
 
     def close(self):
         self.session.close()
